@@ -1,15 +1,20 @@
 package UNIVERSAL::isa;
+BEGIN {
+  $UNIVERSAL::isa::VERSION = '1.20110613';
+}
+# ABSTRACT: Attempt to recover from people calling UNIVERSAL::isa as a function
 
 use strict;
-use vars qw( $VERSION $recursing );
+use warnings;
+use 5.6.2;
+
+use vars qw( $recursing );
 
 use UNIVERSAL ();
 
 use Scalar::Util 'blessed';
 use warnings::register;
 
-$VERSION = '1.01';
-
 my ( $orig, $verbose_warning );
 
 BEGIN { $orig = \&UNIVERSAL::isa }
@@ -100,8 +105,7 @@ __END__
 
 =head1 NAME
 
-UNIVERSAL::isa - Attempt to recover from people calling UNIVERSAL::isa as a
-function
+UNIVERSAL::isa - recover from people calling UNIVERSAL::isa as a function
 
 =head1 SYNOPSIS
 
@@ -127,6 +131,9 @@ the appropriate method on those objects
 
 In all other cases, the real C<UNIVERSAL::isa> gets called directly.
 
+B<NOTE:> You should use this module only for debugging purposes. It does not
+belong as a dependency in running code.
+
 =head1 WARNINGS
 
 If the lexical warnings pragma is available, this module will emit a warning
@@ -151,6 +158,8 @@ usually suggest proper fixes.
 
 =head1 SEE ALSO
 
+L<Perl::Critic::Policy::BuiltinFunctions::ProhibitUniversalIsa>
+
 L<UNIVERSAL::can> for another discussion of the problem at hand.
 
 L<Test::MockObject> for one example of a module that really needs to override
@@ -169,6 +178,6 @@ Yuval Kogman <nothingmuch@woobling.org>
 
 =head1 COPYRIGHT & LICENSE
 
-Artistic Licence 2.0, (c) 2005 - 2008.
+Artistic Licence 2.0, (c) 2005 - 2011.
 
 =cut
